@@ -1,10 +1,12 @@
 #' Numeric Values Formatting
 #'
 #' @param x Numeric value.
-#' @param digits Number of significant digits. May also be \code{"scientific"}
-#'   to return scientific notation. For the latter case, control the number of
-#'   digits by adding the value as suffix, e.g. \code{digits = "scientific4"}
-#'   to have scientific notation with 4 decimal places.
+#' @param digits Number of digits for rounding or significant figures. May also
+#'   be \code{"signif"} to return significant figures or \code{"scientific"}
+#'   to return scientific notation. Control the number of digits by adding the
+#'   value as suffix, e.g. \code{digits = "scientific4"} to have scientific
+#'   notation with 4 decimal places, or \code{digits = "signif5"} for 5
+#'   significant figures (see also \code{\link{signif}}).
 #' @param protect_integers Should integers be kept as integers (i.e., without
 #'   decimals)?
 #' @param missing Value by which \code{NA} values are replaced. By default, an
@@ -32,6 +34,11 @@
 #' format_value(c(0.0045, .12, .34), digits = "scientific")
 #' format_value(c(0.0045, .12, .34), digits = "scientific2")
 #'
+#' # default
+#' format_value(c(0.0045, .123, .345))
+#' # significant figures
+#' format_value(c(0.0045, .123, .345), digits = "signif")
+#'
 #' format_value(as.factor(c("A", "B", "A")))
 #' format_value(iris$Species)
 #'
@@ -120,17 +127,18 @@ format_value.logical <- format_value.numeric
     } else {
       if (is.character(digits) && grepl("^scientific", digits)) {
         digits <- tryCatch(
-          {
-            as.numeric(gsub("scientific", "", digits, fixed = TRUE))
-          },
-          error = function(e) {
-            NA
-          }
+          expr = { as.numeric(gsub("scientific", "", digits, fixed = TRUE)) },
+          error = function(e) { 5 }
         )
-        if (is.na(digits)) {
-          digits <- 5
-        }
+        if (is.na(digits)) digits <- 5
         x <- sprintf("%.*e", digits, x)
+      } else if (is.character(digits) && grepl("^signif", digits)) {
+        digits <- tryCatch(
+          expr = { as.numeric(gsub("signif", "", digits, fixed = TRUE)) },
+          error = function(e) { NA }
+        )
+        if (is.na(digits)) digits <- 3
+        x <- as.character(signif(x, digits))
       } else {
         need_sci <- (abs(x) >= 1e+5 | (log10(abs(x)) < -digits)) & x != 0
         if (.zap_small) {
