@@ -150,8 +150,8 @@ get_parameters.selection <- function(x, component = c("all", "selection", "outco
 
 #' @export
 get_parameters.epi.2by2 <- function(x, ...) {
-  coef_names <- grepl(".strata.wald", names(x$massoc), fixed = TRUE)
-  cf <- x$massoc[coef_names]
+  coef_names <- grepl("^([^NNT]*)(\\.strata\\.wald)", names(x$massoc.detail), perl = TRUE)
+  cf <- x$massoc.detail[coef_names]
   names(cf) <- gsub(".strata.wald", "", names(cf), fixed = TRUE)
 
   params <- data.frame(
@@ -720,10 +720,11 @@ get_parameters.afex_aov <- function(x, ...) {
 
 #' @export
 get_parameters.pgmm <- function(x, component = c("conditional", "all"), ...) {
-  s <- summary(x, time.dummies = TRUE)
+  component <- match.arg(component)
+  cs <- stats::coef(summary(x, time.dummies = TRUE, robust = FALSE))
   params <- data.frame(
-    Parameter = rownames(s$coefficients),
-    Estimate = unname(s$coefficients),
+    Parameter = rownames(cs),
+    Estimate = unname(cs[, 1]),
     Component = "conditional",
     stringsAsFactors = FALSE,
     row.names = NULL
