@@ -254,14 +254,14 @@
     "sigma", "nu", "tau", "correlation", "slopes", "cluster", "extra", "scale",
     "marginal", "alpha", "beta", "survival", "infrequent_purchase", "auxiliary",
     "mix", "shiftprop", "phi", "ndt", "hu", "xi", "coi", "zoi", "aux", "dist",
-    "selection", "outcome"
+    "selection", "outcome", "time_dummies"
   )
 }
 
 .aux_elements <- function() {
   c(
     "sigma", "alpha", "beta", "dispersion", "precision", "nu", "tau", "shape",
-    "phi", "ndt", "hu", "xi", "coi", "zoi", "mix", "shiftprop", "auxiliary",
+    "phi", "(phi)", "ndt", "hu", "xi", "coi", "zoi", "mix", "shiftprop", "auxiliary",
     "aux", "dist"
   )
 }
