@@ -1,8 +1,6 @@
 if (require("testthat") &&
   require("insight") &&
   require("gamlss")) {
-  context("insight, model_info")
-
   data(abdom)
   m1 <-
     gamlss(
@@ -57,7 +55,8 @@ if (require("testthat") &&
         sigma = as.formula("~pb(x)"),
         nu = as.formula("~1"),
         tau = as.formula("~1")
-      )
+      ),
+      ignore_attr = TRUE
     )
   })
 
