@@ -1,8 +1,6 @@
 if (require("testthat") &&
   require("insight") &&
   require("survival")) {
-  data("ovarian", package = "survival")
-  data("lung", package = "survival")
   m1 <- survreg(Surv(futime, fustat) ~ ecog.ps + rx,
     data = ovarian,
     dist = "exponential"
